@@ -15,7 +15,7 @@ pub fn get_disk_list() -> Vec<Vec<String>> {
                 ]);
             }
         }
-        Err(x) => println!("\nget_disk_list: error: {}", x),
+        Err(x) => println!("\nget_disk_list error: {}", x),
     }
     re
 }
